#!/usr/bin/env node

const axios = require('axios');
const ora = require('ora');
const program = require('commander');

program
	.version('0.1.0')
	.option('-u, --url [address]', 'URL to test')
	.option('-r, --requests [number]', 'No. of requests to make (Default 100)')
	.parse(process.argv);

const URL = program.url;
const noOfRequests = program.requests ? program.requests : 100;
let info = ora(`Preparing request`);
info.succeed(`Will test ${URL} with ${noOfRequests} requests`);
let progressSpinner = ora(`Got response 0 of ${noOfRequests}`);

let pro = [];
let currentResponse = 0;

for (let i = 0; i < noOfRequests; i++) {
	pro.push(new Promise((resolve, reject) => {
			axios
				.get(URL)
				.then((res) => {
					updateProgress();
					resolve(true);
				})
				.catch(() => {
					updateProgress();
					resolve(false);
				});
		}));
}

function updateProgress() {
	currentResponse += 1;
	progressSpinner.text = `Got response ${currentResponse} of ${noOfRequests}`;
	progressSpinner.render();
}

Promise.all(pro).then((results) => {
	progressSpinner.succeed('Got all responses');
	let total = results.length;
	let success = results.filter((d) => d === true).length;
	let fail = results.filter((d) => d === false).length;
	console.log('/***** RESULTS *****/');
	console.log('Success', success, `[${(success * 100) / total}%]`);
	console.log('Fail', fail, `[${(fail * 100) / total}%]`);
});
